
import java.io.*;

/**
 *  Classe per l’acquisizione di stringhe e numeri dallo
 *  standard input.
 */
public class ConsoleInput {
  BufferedReader reader;

  /**
   *  Costruisce un oggetto di tipo BufferedReader sopra lo
   *  standard input (System.in).
   */
   public ConsoleInput() {
     reader = new BufferedReader(new InputStreamReader(System.in));
   }

  /**
   *  Legge una riga in input e la converte in un valore intero:
   *  la linea deve contenere un solo valore intero eventualmente
   *  preceduto dal segno, ma senza altri caratteri.
   *  @return valore intero digitato
   */
   public int readInt() {
     int tmp;
     
     try {
          tmp = Integer.parseInt(reader.readLine());
         }
     catch (IOException ex) {
         tmp = 0;
     }
     
     return tmp;
   }

  /**
   *  Legge una riga in input e la converte in un valore floating-
   *  point: la linea deve contenere un solo valore decimale
   *  eventualmente preceduto dal segno, ma senza altri caratteri.
   *  @return valore decimale digitato
   */
   public double readDouble() {
     double tmp;
     
     try {
          tmp = Double.parseDouble(reader.readLine());
         }
     catch (IOException ex) {
         tmp = 0.0;
     }
     
     return tmp;
   }

  /**
   *  Legge una riga di testo in input.
   *  @return stringa digitata
   */
   public String readLine() {
     String tmp;
     
     try {
        tmp = reader.readLine();
     }
     catch (IOException ex) {
         tmp = "";
     }
     
     return tmp;
   }
}
